@@ -1,7 +1,6 @@
 import os
 from collections import defaultdict
-from typing import Mapping  # noqa
-from typing import Any, Dict, Optional, Tuple, cast
+from typing import Any, Dict, Mapping, Optional, Sequence, Tuple, cast
 
 from _pytest.config import Config
 from _pytest.terminal import TerminalReporter
@@ -10,7 +9,7 @@ from pytablewriter.style import Cell, Style
 from typepy import Bool, Integer, StrictLevel
 from typepy.error import TypeConversionError
 
-from ._const import BGColor, ColorPoicy, Default, FGColor, Header, HelpMsg, Option, ZerosRender
+from ._const import BGColor, ColorPolicy, Default, FGColor, Header, HelpMsg, Option, ZerosRender
 
 
 def zero_to_nullstr(value) -> str:
@@ -40,7 +39,7 @@ def pytest_addoption(parser):
     )
     group.addoption(
         Option.MD_REPORT_COLOR.cmdoption_str,
-        choices=ColorPoicy.LIST,
+        choices=ColorPolicy.LIST,
         default=None,
         help=Option.MD_REPORT_COLOR.help_msg
         + HelpMsg.EXTRA_MSG_TEMPLATE.format(Option.MD_REPORT_COLOR.envvar_str),
@@ -138,8 +137,10 @@ def is_make_md_report(config: Config) -> bool:
 
 def _is_ci() -> bool:
     CI = os.environ.get("CI")
+    if not CI:
+        return False
 
-    return CI and CI.lower() == "true"
+    return CI.lower() == "true"
 
 
 def _is_travis_ci() -> bool:
@@ -150,8 +151,10 @@ def _is_travis_ci() -> bool:
 def _is_appveyor_ci() -> bool:
     # https://www.appveyor.com/docs/environment-variables/
     APPVEYOR = os.environ.get("APPVEYOR")
+    if not APPVEYOR:
+        return False
 
-    return APPVEYOR and APPVEYOR.lower() == "true"
+    return APPVEYOR.lower() == "true"
 
 
 def _to_int(value) -> Optional[int]:
@@ -273,10 +276,10 @@ class ColorRetriever:
 
         if (self.__row % 2) == 0:
             fg_color = self.__color_map[FGColor.GRAYOUT] if self.__is_grayout else base_color
-            bg_color = BGColor.EVEN_ROW if self.__report_color == ColorPoicy.AUTO else None
+            bg_color = BGColor.EVEN_ROW if self.__report_color == ColorPolicy.AUTO else None
         else:
             fg_color = self.__color_map[FGColor.GRAYOUT] if self.__is_grayout else base_color
-            bg_color = BGColor.ODD_ROW if self.__report_color == ColorPoicy.AUTO else None
+            bg_color = BGColor.ODD_ROW if self.__report_color == ColorPolicy.AUTO else None
 
         return (fg_color, bg_color)
 
@@ -361,13 +364,9 @@ def col_separator_style_filter(
     return None
 
 
-def make_md_report(
-    config: Config, reporter: TerminalReporter, total_stats: Mapping[str, int]
-) -> str:
-    verbosity_level = retrieve_verbosity_level(config)
-
-    outcomes = ["passed", "failed", "error", "skipped", "xfailed", "xpassed"]
-    outcomes = [key for key in outcomes if total_stats.get(key, 0) > 0]
+def extract_pytest_stats(
+    reporter: TerminalReporter, outcomes: Sequence[str], verbosity_level: int
+) -> Mapping[Tuple, Mapping[str, int]]:
     results_per_testfunc = {}  # type: Dict[Tuple, Dict[str, int]]
 
     for stat_key, values in reporter.stats.items():
@@ -391,6 +390,20 @@ def make_md_report(
                 results_per_testfunc[key] = defaultdict(int)
             results_per_testfunc[key][stat_key] += 1
 
+    return results_per_testfunc
+
+
+def make_md_report(
+    config: Config, reporter: TerminalReporter, total_stats: Mapping[str, int]
+) -> str:
+    verbosity_level = retrieve_verbosity_level(config)
+
+    outcomes = ["passed", "failed", "error", "skipped", "xfailed", "xpassed"]
+    outcomes = [key for key in outcomes if total_stats.get(key, 0) > 0]
+    results_per_testfunc = extract_pytest_stats(
+        reporter=reporter, outcomes=outcomes, verbosity_level=verbosity_level
+    )
+
     writer = TableWriterFactory.create_from_format_name("md")
 
     matrix = [
@@ -408,7 +421,7 @@ def make_md_report(
     writer.value_matrix = matrix
 
     report_color = retrieve_report_color(config)
-    if report_color != ColorPoicy.NEVER:
+    if report_color != ColorPolicy.NEVER:
         writer.style_filter_kwargs = {
             "report_color": report_color,
             "color_map": {
@@ -429,7 +442,7 @@ def make_md_report(
         if not _is_travis_ci():
             writer.add_style_filter(style_filter)
 
-        if report_color == ColorPoicy.AUTO and not _is_ci():
+        if report_color == ColorPolicy.AUTO and not _is_ci():
             writer.add_col_separator_style_filter(col_separator_style_filter)
 
     report_zeros = retrieve_report_zeros(config)
