@@ -13,6 +13,14 @@ PYFILE_PASS_TEST = dedent(
         assert True
     """
 )
+PYFILE_SKIP_TEST = dedent(
+    """\
+    import pytest
+
+    def test_skipped():
+        pytest.skip()
+    """
+)
 PYFILE_MIX_TESTS = dedent(
     """\
     import pytest
@@ -58,10 +66,10 @@ def test_pytest_md_report(testdir):
     testdir.makepyfile(PYFILE_MIX_TESTS)
     expected = dedent(
         """\
-        |         filepath         | passed | failed | error | skipped | xfailed | xpassed |
-        |--------------------------|-------:|-------:|------:|--------:|--------:|--------:|
-        | test_pytest_md_report.py |      1 |      1 |     1 |       1 |       1 |       1 |
-        | TOTAL                    |      1 |      1 |     1 |       1 |       1 |       1 |"""
+        |         filepath         | passed | failed | error | skipped | xfailed | xpassed | SUBTOTAL |
+        |--------------------------|-------:|-------:|------:|--------:|--------:|--------:|---------:|
+        | test_pytest_md_report.py |      1 |      1 |     1 |       1 |       1 |       1 |        6 |
+        | TOTAL                    |      1 |      1 |     1 |       1 |       1 |       1 |        6 |"""
     )
     result = testdir.runpytest("--md-report", "--md-report-color", "never")
     out = "\n".join(result.outlines[-4:])
@@ -74,10 +82,10 @@ def test_pytest_md_report_margin(testdir):
     testdir.makepyfile(PYFILE_MIX_TESTS)
     expected = dedent(
         """\
-        |           filepath            |passed|failed|error|skipped|xfailed|xpassed|
-        |-------------------------------|-----:|-----:|----:|------:|------:|------:|
-        |test_pytest_md_report_margin.py|     1|     1|    1|      1|      1|      1|
-        |TOTAL                          |     1|     1|    1|      1|      1|      1|"""
+        |           filepath            |passed|failed|error|skipped|xfailed|xpassed|SUBTOTAL|
+        |-------------------------------|-----:|-----:|----:|------:|------:|------:|-------:|
+        |test_pytest_md_report_margin.py|     1|     1|    1|      1|      1|      1|       6|
+        |TOTAL                          |     1|     1|    1|      1|      1|      1|       6|"""
     )
     result = testdir.runpytest(
         "--md-report", "--md-report-color", "never", "--md-report-margin", "0"
@@ -89,18 +97,21 @@ def test_pytest_md_report_margin(testdir):
 
 
 def test_pytest_md_report_zeros(testdir):
-    testdir.makepyfile(PYFILE_PASS_TEST)
+    testdir.makepyfile(test_passed=PYFILE_PASS_TEST)
+    testdir.makepyfile(test_skipped=PYFILE_SKIP_TEST)
+
     expected = dedent(
         """\
-        |            filepath            | passed | failed | error | skipped | xfailed | xpassed |
-        |--------------------------------|-------:|--------|-------|---------|---------|---------|
-        | test_pytest_md_report_zeros.py |      1 |        |       |         |         |         |
-        | TOTAL                          |      1 |        |       |         |         |         |"""
+        |    filepath     | passed | skipped | SUBTOTAL |
+        |-----------------|-------:|--------:|---------:|
+        | test_passed.py  |      1 |         |        1 |
+        | test_skipped.py |        |       1 |        1 |
+        | TOTAL           |      1 |       1 |        2 |"""
     )
     result = testdir.runpytest(
         "--md-report", "--md-report-color", "never", "--md-report-zeros", "empty"
     )
-    out = "\n".join(result.outlines[-4:])
+    out = "\n".join(result.outlines[-5:])
     print_test_result(expected=expected, actual=out)
 
     assert out == expected
@@ -110,7 +121,7 @@ def test_pytest_md_report_zeros(testdir):
     ["color_option"],
     [["--md-report-success-color"], ["--md-report-skip-color"], ["--md-report-error-color"]],
 )
-def test_pytest_md_report_resu(testdir, color_option):
+def test_pytest_md_report_results_color(testdir, color_option):
     testdir.makepyfile(PYFILE_MIX_TESTS)
     org_out = "\n".join(testdir.runpytest("--md-report").outlines[-4:])
     ch_color_out = "\n".join(
